==> haskell-temporary-1.3-9-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-temporary.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: temporary
version: 1.3
id: temporary-1.3-9IxYk8pkVXF9czeubVUZPj
key: temporary-1.3-9IxYk8pkVXF9czeubVUZPj
license: BSD-3-Clause
maintainer: Mateusz Kowalczyk <fuuzetsu@fuuzetsu.co.uk>, Roman Cheplyaka <roma@ro-che.info>
homepage: https://github.com/feuerbach/temporary
synopsis: Portable temporary file and directory support
description:
    Functions for creating temporary files and directories.
category: System, Utils
abi: 8c49ba414a57a9d4be6d5ca675bed1f1
exposed: True
exposed-modules:
    System.IO.Temp
import-dirs: /usr/lib/ghc-8.4.3/site-local/temporary-1.3
library-dirs: /usr/lib/ghc-8.4.3/site-local/temporary-1.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/temporary-1.3
hs-libraries: HStemporary-1.3-9IxYk8pkVXF9czeubVUZPj
depends:
    base-4.11.1.0 filepath-1.4.2 directory-1.3.1.5 transformers-0.5.5.0
    exceptions-0.10.0-7FqenMMTX3xHtUICKpGQUY
    random-1.1-9LLJAJa4iQFLJiLXBOBXBV unix-2.7.2.2
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             filepath-1.4.2=f8b35940dbf3bb5331e1c5ab9738687d
             directory-1.3.1.5=e563da47c8e71ee27761a9b9d172f1ec
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             exceptions-0.10.0-7FqenMMTX3xHtUICKpGQUY=1e7acabe11915a69b3faf108407a56c7
             random-1.1-9LLJAJa4iQFLJiLXBOBXBV=8df244958947206247b1dd733653312e
             unix-2.7.2.2=5200b6eb79607eed6537538f20d679bf
haddock-interfaces: /usr/share/doc/haskell-temporary/html/temporary.haddock
haddock-html: /usr/share/doc/haskell-temporary/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-temporary-1.3-10-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-temporary.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: temporary
version: 1.3
id: temporary-1.3-EBuERSEmtHXE85JeaX8qjS
key: temporary-1.3-EBuERSEmtHXE85JeaX8qjS
license: BSD-3-Clause
maintainer: Mateusz Kowalczyk <fuuzetsu@fuuzetsu.co.uk>, Roman Cheplyaka <roma@ro-che.info>
homepage: https://github.com/feuerbach/temporary
synopsis: Portable temporary file and directory support
description:
    Functions for creating temporary files and directories.
category: System, Utils
abi: 01d519c7432efc4de9e320255c42d692
exposed: True
exposed-modules:
    System.IO.Temp
import-dirs: /usr/lib/ghc-8.4.3/site-local/temporary-1.3
library-dirs: /usr/lib/ghc-8.4.3/site-local/temporary-1.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/temporary-1.3
hs-libraries: HStemporary-1.3-EBuERSEmtHXE85JeaX8qjS
depends:
    base-4.11.1.0 filepath-1.4.2 directory-1.3.1.5 transformers-0.5.5.0
    exceptions-0.10.0-IRO0p79DXGKGDsbbDc50a8
    random-1.1-9LLJAJa4iQFLJiLXBOBXBV unix-2.7.2.2
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             filepath-1.4.2=f8b35940dbf3bb5331e1c5ab9738687d
             directory-1.3.1.5=e563da47c8e71ee27761a9b9d172f1ec
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             exceptions-0.10.0-IRO0p79DXGKGDsbbDc50a8=e9779fb859fee3584d68df46d12eac41
             random-1.1-9LLJAJa4iQFLJiLXBOBXBV=8df244958947206247b1dd733653312e
             unix-2.7.2.2=5200b6eb79607eed6537538f20d679bf
haddock-interfaces: /usr/share/doc/haskell-temporary/html/temporary.haddock
haddock-html: /usr/share/doc/haskell-temporary/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
